============
Installation
============

At the command line::

    $ pip install liquimigrate

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv liquimigrate
    $ pip install liquimigrate
